@@ -8,7 +8,7 @@
 #define OR_BLACK         (0)
 #define OR_WHITE         (1)
 #define OR_BLUE          (2)
-#define OR_FAINT_BLUE    (3)
+#define OR_ORANGE        (3)
 #define OR_GREY          (4)
 #define OR_DARK_GREY     (5)
 #define OR_GREEN         (6)
@@ -20,7 +20,7 @@
 #define OR_CREAM        (12)
 #define OR_DARK_CREAM   (13)
 #define OR_BLUE_GREEN   (14)
-#define OR_FAINT_GOLD   (15)
+#define OR_YELLOW_GREEN (15)
 #define OR_PINK         (16)
 #define OR_PURPLE       (17)
 #define OR_FAINT_YELLOW (18)
@@ -29,7 +29,7 @@ unsigned short orreryColorRGB[N_COLORS][3] =
   {{    0,     0,     0}, /* Black        */
    {MAX16, MAX16, MAX16}, /* White        */
    {20000, 20000, MAX16}, /* Blue         */
-   {21000, 21000, 45875}, /* Faint Blue   */
+   {MAX16, 32767,     0}, /* Orange       */
    {41000, 41000, 41000}, /* Grey         */
    {20000, 18000, 20000}, /* Dark Grey    */
    {    0, MAX16,     0}, /* Green        */
@@ -41,7 +41,7 @@ unsigned short orreryColorRGB[N_COLORS][3] =
    {MAX16, MAX16, 40000}, /* Cream        */
    {39321, 39321, 24000}, /* Dark Cream   */
    {    0, 20000, 20000}, /* Blue Green   */
-   {MAX16, 25000,     0}, /* Faint Gold   */
+   {43000, MAX16,     0}, /* Yellow Green */
    {MAX16, 25000, 35000}, /* Pink         */
    {MAX16,     0, MAX16}, /* Purple       */
    {52000, 52000, 35000}  /* Faint Yellow */
